<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>AppChooserDialog</name>
    <message>
        <location filename="../app-chooser-dialog.ui" line="14"/>
        <source>Choose an Application</source>
        <translation>Выбрать приложение</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="36"/>
        <source>Installed Applications</source>
        <translation>Установленные приложения</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="46"/>
        <source>Custom Command</source>
        <translation>Своя команда</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="52"/>
        <source>Command line to execute:</source>
        <translation>Выполняемая командная строка:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="62"/>
        <source>Application name:</source>
        <translation>Имя приложения:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="72"/>
        <source>&lt;b&gt;These special codes can be used in the command line:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Represents a single file name&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Represents multiple file names&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Represents a single URI of the file&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Represents multiple URIs&lt;/li&gt;
&lt;/ul&gt;</source>
        <translation>&lt;b&gt;Эти спец. коды могут быть использованы в командной строке:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Означает имя одного файла&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Означает имена нескольких файлов&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Означает один URI файла&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Означает несколько URI файлов&lt;/li&gt;
&lt;/ul&gt;</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="91"/>
        <source>Keep terminal window open after command execution</source>
        <translation>Держать окно терминала открытым после выполнения команды</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="98"/>
        <source>Execute in terminal emulator</source>
        <translation>Запустить в эмуляторе терминала</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="109"/>
        <source>Set selected application as default action of this file type</source>
        <translation>Использовать выбранное приложение как действие по умолчанию для файлов этого типа</translation>
    </message>
</context>
<context>
    <name>EditBookmarksDialog</name>
    <message>
        <location filename="../edit-bookmarks.ui" line="14"/>
        <source>Edit Bookmarks</source>
        <translation>Изменить закладки</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="42"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="47"/>
        <source>Location</source>
        <translation>Расположение</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="67"/>
        <source>&amp;Add Item</source>
        <translation>&amp;Добавить пункт</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="77"/>
        <source>&amp;Remove Item</source>
        <translation>&amp;Удалить пункт</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="102"/>
        <source>Use drag and drop to reorder the items</source>
        <translation>Используйте перетаскивание и отпускание для переупорядочивания пунктов</translation>
    </message>
</context>
<context>
    <name>ExecFileDialog</name>
    <message>
        <location filename="../exec-file.ui" line="14"/>
        <source>Execute file</source>
        <translation>Выполнить файл</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="39"/>
        <source>&amp;Open</source>
        <translation>&amp;Открыть</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="52"/>
        <source>E&amp;xecute</source>
        <translation>В&amp;ыполнить</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="62"/>
        <source>Execute in &amp;Terminal</source>
        <translation>Выполнить в &amp;терминале</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="85"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>FileOperationDialog</name>
    <message>
        <location filename="../file-operation-dialog.ui" line="32"/>
        <source>Destination:</source>
        <translation>Назначение:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="55"/>
        <source>Processing:</source>
        <translation>Обработка:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="68"/>
        <source>Preparing...</source>
        <translation>Подготовка...</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="75"/>
        <source>Progress</source>
        <translation>Прогресс</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="95"/>
        <source>Time remaining:</source>
        <translation>Времени осталось:</translation>
    </message>
</context>
<context>
    <name>FilePropsDialog</name>
    <message>
        <location filename="../file-props.ui" line="14"/>
        <source>File Properties</source>
        <translation>Свойства файла</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="41"/>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="80"/>
        <source>Location:</source>
        <translation>Расположение:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="106"/>
        <source>File type:</source>
        <translation>Тип файла:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="129"/>
        <source>Mime type:</source>
        <translation>Тип Mime:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="152"/>
        <source>File size:</source>
        <translation>Размер файла:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="175"/>
        <source>On-disk size:</source>
        <translation>Размер на диске:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="198"/>
        <source>Last modified:</source>
        <translation>Последнее изменение:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="221"/>
        <source>Link target:</source>
        <translation>Цель ссылки:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="247"/>
        <source>Open With:</source>
        <translation>Открыть с помощью:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="267"/>
        <source>Last accessed:</source>
        <translation>Последний доступ:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="285"/>
        <source>Permissions</source>
        <translation>Разрешения</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="300"/>
        <source>Ownership</source>
        <translation>Владение</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="324"/>
        <location filename="../file-props.ui" line="389"/>
        <location filename="../file-props.ui" line="503"/>
        <source>Group:</source>
        <translation>Группа:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="337"/>
        <location filename="../file-props.ui" line="372"/>
        <location filename="../file-props.ui" line="451"/>
        <source>Owner:</source>
        <translation>Владелец:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="353"/>
        <source>Access Control</source>
        <translation>Контроль доступа</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="406"/>
        <location filename="../file-props.ui" line="555"/>
        <source>Other:</source>
        <translation>Остальные:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="423"/>
        <source>Make the file executable</source>
        <translation>Сделать файл исполняемым</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="464"/>
        <location filename="../file-props.ui" line="516"/>
        <location filename="../file-props.ui" line="568"/>
        <source>Read</source>
        <translation>Чтение</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="477"/>
        <location filename="../file-props.ui" line="529"/>
        <location filename="../file-props.ui" line="581"/>
        <source>Write</source>
        <translation>Запись</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="490"/>
        <location filename="../file-props.ui" line="542"/>
        <location filename="../file-props.ui" line="594"/>
        <source>Execute</source>
        <translation>Выполнение</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="603"/>
        <source>Sticky</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="610"/>
        <source>SetUID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="617"/>
        <source>SetGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="653"/>
        <source>Advanced Mode</source>
        <translation>Расширенный режим</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserComboBox</name>
    <message>
        <location filename="../appchoosercombobox.cpp" line="79"/>
        <source>Customize</source>
        <translation>Настроить</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserDialog</name>
    <message>
        <location filename="../appchooserdialog.cpp" line="262"/>
        <source>Select an application to open &quot;%1&quot; files</source>
        <translation>Выберите приложение, чтобы открыть &quot;%1&quot; файлов</translation>
    </message>
</context>
<context>
    <name>Fm::CreateNewMenu</name>
    <message>
        <location filename="../createnewmenu.cpp" line="29"/>
        <source>Folder</source>
        <translation>Папку</translation>
    </message>
    <message>
        <location filename="../createnewmenu.cpp" line="33"/>
        <source>Blank File</source>
        <translation>Пустой файл</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeModel</name>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="77"/>
        <source>Loading...</source>
        <translation>Загрузка...</translation>
    </message>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="208"/>
        <source>&lt;No sub folders&gt;</source>
        <translation>&lt;Нет подпапок&gt;</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeView</name>
    <message>
        <location filename="../dirtreeview.cpp" line="208"/>
        <source>Open in New T&amp;ab</source>
        <translation>Открыть в новой вкл&amp;адке</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="212"/>
        <source>Open in New Win&amp;dow</source>
        <translation>Открыть в новом о&amp;кне</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="217"/>
        <source>Open in Termina&amp;l</source>
        <translation>Открыть в термина&amp;ле</translation>
    </message>
</context>
<context>
    <name>Fm::DndActionMenu</name>
    <message>
        <location filename="../dndactionmenu.cpp" line="26"/>
        <source>Copy here</source>
        <translation>Копировать сюда</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="27"/>
        <source>Move here</source>
        <translation>Переместить сюда</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="28"/>
        <source>Create symlink here</source>
        <translation>Создать здесь ссылку</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="30"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>Fm::EditBookmarksDialog</name>
    <message>
        <location filename="../editbookmarksdialog.cpp" line="96"/>
        <source>New bookmark</source>
        <translation>Новая закладка</translation>
    </message>
</context>
<context>
    <name>Fm::ExecFileDialog</name>
    <message>
        <location filename="../execfiledialog.cpp" line="40"/>
        <source>This text file &apos;%1&apos; seems to be an executable script.
What do you want to do with it?</source>
        <translation>Этот текстовый файл &apos;%1&apos; похож на исполняемый скрипт.
Что вы хотите с ним сделать?</translation>
    </message>
    <message>
        <location filename="../execfiledialog.cpp" line="45"/>
        <source>This file &apos;%1&apos; is executable. Do you want to execute it?</source>
        <translation>Это исполняемый файл &apos;%1&apos; . Вы хотите выполнить его?</translation>
    </message>
</context>
<context>
    <name>Fm::FileMenu</name>
    <message>
        <location filename="../filemenu.cpp" line="94"/>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="98"/>
        <source>Open With...</source>
        <translation>Открыть с помощью...</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="126"/>
        <source>Other Applications</source>
        <translation>Другие приложения</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="132"/>
        <source>Create &amp;New</source>
        <translation>&amp;Создать</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="151"/>
        <source>&amp;Restore</source>
        <translation>&amp;Восстановить</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="157"/>
        <source>Cut</source>
        <translation>Вырезать</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="161"/>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="165"/>
        <source>Paste</source>
        <translation>Вставить</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="169"/>
        <location filename="../filemenu.cpp" line="363"/>
        <source>&amp;Move to Trash</source>
        <translation>&amp;Переместить в корзину</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="173"/>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="200"/>
        <source>Extract to...</source>
        <translation>Распаковать в ...</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="205"/>
        <source>Extract Here</source>
        <translation>Распаковать здесь</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="211"/>
        <source>Compress</source>
        <translation>Сжать</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="221"/>
        <source>Properties</source>
        <translation>Свойства</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="312"/>
        <source>Output</source>
        <translation>Вывод</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="363"/>
        <source>&amp;Delete</source>
        <translation>&amp;Удалить</translation>
    </message>
</context>
<context>
    <name>Fm::FileOperation</name>
    <message>
        <location filename="../fileoperation.cpp" line="220"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="221"/>
        <source>Some files cannot be moved to trash can because the underlying file systems don&apos;t support this operation.
Do you want to delete them instead?</source>
        <translation>Некоторые файлы не могут быть помещены в корзину, поскольку файловая система не поддерживает эту операцию.
Вы всё равно хотите их удалить?</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="262"/>
        <location filename="../fileoperation.cpp" line="278"/>
        <source>Confirm</source>
        <translation>Подтвердить</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="263"/>
        <source>Do you want to delete the selected files?</source>
        <translation>Вы действительно хотите удалить выбранные файлы?</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="279"/>
        <source>Do you want to move the selected files to trash can?</source>
        <translation>Переместить выбранные файлы в корзину?</translation>
    </message>
</context>
<context>
    <name>Fm::FileOperationDialog</name>
    <message>
        <location filename="../fileoperationdialog.cpp" line="41"/>
        <source>Move files</source>
        <translation>Перемещение файлов</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="42"/>
        <source>Moving the following files to destination folder:</source>
        <translation>Перемещение следующих файлов в папку назначения:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="45"/>
        <source>Copy Files</source>
        <translation>Копирование файлов</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="46"/>
        <source>Copying the following files to destination folder:</source>
        <translation>Копирование следующих файлов в папку назначения:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="49"/>
        <source>Trash Files</source>
        <translation>Перемещение в корзину файлов</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="50"/>
        <source>Moving the following files to trash can:</source>
        <translation>Перемещение следующих файлов в корзину:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="53"/>
        <source>Delete Files</source>
        <translation>Удалить файлы</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="54"/>
        <source>Deleting the following files</source>
        <translation>Удаление следующих файлов</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="59"/>
        <source>Create Symlinks</source>
        <translation>Создание ссылок</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="60"/>
        <source>Creating symlinks for the following files:</source>
        <translation>Создание ссылок на следующие файлы:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="63"/>
        <source>Change Attributes</source>
        <translation>Изменение атрибутов</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="64"/>
        <source>Changing attributes of the following files:</source>
        <translation>Изменение атрибутов следующих файлов:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="69"/>
        <source>Restore Trashed Files</source>
        <translation>Восстановить файлы из корзины</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="70"/>
        <source>Restoring the following files from trash can:</source>
        <translation>Восстановление следующих файлов из корзины:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="137"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
</context>
<context>
    <name>Fm::FilePropsDialog</name>
    <message>
        <location filename="../filepropsdialog.cpp" line="145"/>
        <source>View folder content</source>
        <translation>Просмотр содержимого папки</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="146"/>
        <source>View and modify folder content</source>
        <translation>Просмотр и изменение содержимого папки</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="150"/>
        <source>Read</source>
        <translation>Чтение</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="151"/>
        <source>Read and write</source>
        <translation>Чтение и запись</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="153"/>
        <source>Forbidden</source>
        <translation>Запрет</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="257"/>
        <source>Files of different types</source>
        <translation>Файлы разного типа</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="287"/>
        <source>Multiple Files</source>
        <translation>Несколько файлов</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="415"/>
        <source>Apply changes</source>
        <translation>Применить изменения</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="416"/>
        <source>Do you want to recursively apply these changes to all files and sub-folders?</source>
        <translation>Применить изменения рекурсивно ко всем файлам и подпапкам?</translation>
    </message>
</context>
<context>
    <name>Fm::FileSearchDialog</name>
    <message>
        <location filename="../filesearchdialog.cpp" line="120"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="120"/>
        <source>You should add at least add one directory to search.</source>
        <translation>Вы должны добавить не менее одного места для поиска.</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="127"/>
        <source>Select a folder</source>
        <translation>Выберите папку</translation>
    </message>
</context>
<context>
    <name>Fm::FolderMenu</name>
    <message>
        <location filename="../foldermenu.cpp" line="37"/>
        <source>Create &amp;New</source>
        <translation>&amp;Создать</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="44"/>
        <source>&amp;Paste</source>
        <translation>&amp;Вставить</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="50"/>
        <source>Select &amp;All</source>
        <translation>Выбрать &amp;всё</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="54"/>
        <source>Invert Selection</source>
        <translation>Инвертировать выделение</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="60"/>
        <source>Sorting</source>
        <translation>Сортировка</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="65"/>
        <source>Show Hidden</source>
        <translation>Показать скрытые</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="73"/>
        <source>Folder Pr&amp;operties</source>
        <translation>&amp;Свойства папки</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="99"/>
        <source>By File Name</source>
        <translation>По имени</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="100"/>
        <source>By Modification Time</source>
        <translation>По времени изменения</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="101"/>
        <source>By File Size</source>
        <translation>По размеру</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="102"/>
        <source>By File Type</source>
        <translation>По типу</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="103"/>
        <source>By File Owner</source>
        <translation>По владельцу</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="115"/>
        <source>Ascending</source>
        <translation>Возрастающая</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="120"/>
        <source>Descending</source>
        <translation>Убывающая</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="135"/>
        <source>Folder First</source>
        <translation>Сначала папки</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="144"/>
        <source>Case Sensitive</source>
        <translation>Регистрочувствительность</translation>
    </message>
</context>
<context>
    <name>Fm::FolderModel</name>
    <message>
        <location filename="../foldermodel.cpp" line="248"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="251"/>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="254"/>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="257"/>
        <source>Modified</source>
        <translation>Изменён</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="260"/>
        <source>Owner</source>
        <translation>Владелец</translation>
    </message>
</context>
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>Жирный</translation>
    </message>
    <message>
        <location filename="../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>Курсив</translation>
    </message>
</context>
<context>
    <name>Fm::MountOperationPasswordDialog</name>
    <message>
        <location filename="../mountoperationpassworddialog.cpp" line="40"/>
        <source>&amp;Connect</source>
        <translation>&amp;Соединить</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesModel</name>
    <message>
        <location filename="../placesmodel.cpp" line="40"/>
        <source>Places</source>
        <translation>Места</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="48"/>
        <source>Desktop</source>
        <translation>Рабочий стол</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="57"/>
        <source>Computer</source>
        <translation>Компьютер</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="70"/>
        <source>Applications</source>
        <translation>Программы</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="82"/>
        <source>Network</source>
        <translation>Сеть</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="90"/>
        <source>Devices</source>
        <translation>Устройства</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="132"/>
        <source>Bookmarks</source>
        <translation>Закладки</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="207"/>
        <source>Trash</source>
        <translation>Корзина</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesView</name>
    <message>
        <location filename="../placesview.cpp" line="358"/>
        <source>Empty Trash</source>
        <translation>Очистить корзину</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="346"/>
        <source>Open in New Tab</source>
        <translation>Открыть в новой вкладке</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="349"/>
        <source>Open in New Window</source>
        <translation>Открыть в новом окне</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="367"/>
        <source>Move Bookmark Up</source>
        <translation>Сдвинуть закладку вверх</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="372"/>
        <source>Move Bookmark Down</source>
        <translation>Сдвинуть закладку вниз</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="376"/>
        <source>Rename Bookmark</source>
        <translation>Переименовать закладку</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="379"/>
        <source>Remove Bookmark</source>
        <translation>Удалить закладку</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="388"/>
        <location filename="../placesview.cpp" line="405"/>
        <source>Unmount</source>
        <translation>Отключить</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="392"/>
        <source>Mount</source>
        <translation>Подключить</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="398"/>
        <source>Eject</source>
        <translation>Извлечь</translation>
    </message>
</context>
<context>
    <name>Fm::RenameDialog</name>
    <message>
        <location filename="../renamedialog.cpp" line="50"/>
        <location filename="../renamedialog.cpp" line="69"/>
        <source>Type: %1
Size: %2
Modified: %3</source>
        <translation>Тип: %1
Размер: %2
Изменён: %3</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="56"/>
        <source>Type: %1
Modified: %2</source>
        <translation>Тип: %1
Изменён: %2</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="75"/>
        <source>Type: %1
Modified: %3</source>
        <translation>Тип: %1
Изменён: %3</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="89"/>
        <source>&amp;Overwrite</source>
        <translation>&amp;Перезаписать</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="91"/>
        <source>&amp;Rename</source>
        <translation>&amp;Переименовать</translation>
    </message>
</context>
<context>
    <name>Fm::SidePane</name>
    <message>
        <location filename="../sidepane.cpp" line="47"/>
        <location filename="../sidepane.cpp" line="127"/>
        <source>Places</source>
        <translation>Места</translation>
    </message>
    <message>
        <location filename="../sidepane.cpp" line="48"/>
        <location filename="../sidepane.cpp" line="129"/>
        <source>Directory Tree</source>
        <translation>Дерево папок</translation>
    </message>
    <message>
        <location filename="../sidepane.cpp" line="137"/>
        <source>Shows list of common places, devices, and bookmarks in sidebar</source>
        <translation>Показывает список обычных мест, устройств и закладок в боковой панели</translation>
    </message>
    <message>
        <location filename="../sidepane.cpp" line="139"/>
        <source>Shows tree of directories in sidebar</source>
        <translation>Показывает дерево папок в боковой панели</translation>
    </message>
</context>
<context>
    <name>MountOperationPasswordDialog</name>
    <message>
        <location filename="../mount-operation-password.ui" line="20"/>
        <source>Mount</source>
        <translation>Подключить</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="48"/>
        <source>Connect &amp;anonymously</source>
        <translation>Подсоединить &amp;анонимно</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="58"/>
        <source>Connect as u&amp;ser:</source>
        <translation>Подсоединить как &amp;пользователь:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="79"/>
        <source>&amp;Username:</source>
        <translation>&amp;Имя пользователя:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="102"/>
        <source>&amp;Password:</source>
        <translation>&amp;Пароль:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="112"/>
        <source>&amp;Domain:</source>
        <translation>&amp;Домен:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="127"/>
        <source>Forget password &amp;immediately</source>
        <translation>Забыть пароль &amp;сразу</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="137"/>
        <source>Remember password until you &amp;logout</source>
        <translation>Запомнить пароль пока вы не &amp;вышли</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="147"/>
        <source>Remember &amp;forever</source>
        <translation>Запомнить &amp;навсегда</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../utilities.cpp" line="152"/>
        <location filename="../utilities.cpp" line="228"/>
        <location filename="../mountoperation.cpp" line="185"/>
        <location filename="../filelauncher.cpp" line="117"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="123"/>
        <source>Rename File</source>
        <translation>Переименовать файл</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="124"/>
        <source>Please enter a new name:</source>
        <translation>Введите новое имя:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="164"/>
        <source>Create Folder</source>
        <translation>Создать папку</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="169"/>
        <source>Please enter a new file name:</source>
        <translation>Введите имя нового файла:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="170"/>
        <source>New text file</source>
        <translation>Новый текстовый файл</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="174"/>
        <source>Please enter a new folder name:</source>
        <translation>Введите имя новой папки:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="175"/>
        <source>New folder</source>
        <translation>Новая папка</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="180"/>
        <source>Enter a name for the new %1:</source>
        <translation>Введите имя для нового %1:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="165"/>
        <source>Create File</source>
        <translation>Создать файл</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <location filename="../rename-dialog.ui" line="14"/>
        <source>Confirm to replace files</source>
        <translation>Подтвердить замену файлов</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="35"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;There is already a file with the same name in this location.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Do you want to replace the existing file?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;В этом месте назначения уже есть файл с таким именем.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Вы хотите заменить существующий файл?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="56"/>
        <source>dest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="63"/>
        <source>with the following file?</source>
        <translation>следующим файлом?</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="76"/>
        <source>src file info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="89"/>
        <source>dest file info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="102"/>
        <source>src</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="122"/>
        <source>&amp;File name:</source>
        <translation>&amp;Имя файла:</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="137"/>
        <source>Apply this option to all existing files</source>
        <translation>Запомнить выбор для всех уже существующих файлов</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../filesearch.ui" line="14"/>
        <source>Search Files</source>
        <translation>Искать файлы</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="29"/>
        <source>Name/Location</source>
        <translation>Имя/Расположение</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="35"/>
        <source>File Name Patterns:</source>
        <translation>Шаблоны имени файла:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="41"/>
        <source>*</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="48"/>
        <source>Case insensitive</source>
        <translation>Нечувствительный к регистру поиск</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="55"/>
        <source>Use regular expression</source>
        <translation>Использовать регулярные выражения</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="65"/>
        <source>Places to Search:</source>
        <translation>Места для поиска:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="78"/>
        <source>&amp;Add</source>
        <translation>&amp;Добавить</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="90"/>
        <source>&amp;Remove</source>
        <translation>&amp;Удалить</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="119"/>
        <source>Search in sub directories</source>
        <translation>Искать в подпапках</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="126"/>
        <source>Search for hidden files</source>
        <translation>Искать скрытые файлы</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="137"/>
        <source>File Type</source>
        <translation>Тип файла</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="143"/>
        <source>Only search for files of following types:</source>
        <translation>Искать файлы только следующих типов:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="149"/>
        <source>Text files</source>
        <translation>Текстовые файлы</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="156"/>
        <source>Image files</source>
        <translation>Изображения</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="163"/>
        <source>Audio files</source>
        <translation>Аудиофайлы</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="170"/>
        <source>Video files</source>
        <translation>Видеофайлы</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="177"/>
        <source>Documents</source>
        <translation>Документы</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="184"/>
        <source>Folders</source>
        <translation>Папки</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="208"/>
        <source>Content</source>
        <translation>Содержание</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="214"/>
        <source>File contains:</source>
        <translation>Файл содержит:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="223"/>
        <source>Case insensiti&amp;ve</source>
        <translation>Нечувствительн&amp;ый к регистру поиск</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="230"/>
        <source>&amp;Use regular expression</source>
        <translation>&amp;Использовать регулярные выражения</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="254"/>
        <source>Properties</source>
        <translation>Свойства</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="260"/>
        <source>File Size:</source>
        <translation>Размер файла:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="266"/>
        <source>Larger than:</source>
        <translation>Больше, чем:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="282"/>
        <location filename="../filesearch.ui" line="323"/>
        <source>Bytes</source>
        <translation>Байт</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="287"/>
        <location filename="../filesearch.ui" line="328"/>
        <source>KiB</source>
        <translation>КиБ</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="292"/>
        <location filename="../filesearch.ui" line="333"/>
        <source>MiB</source>
        <translation>МиБ</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="297"/>
        <location filename="../filesearch.ui" line="338"/>
        <source>GiB</source>
        <translation>ГиБ</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="307"/>
        <source>Smaller than:</source>
        <translation>Меньше, чем:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="351"/>
        <source>Last Modified Time:</source>
        <translation>Время последнего изменения:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="357"/>
        <source>Earlier than:</source>
        <translation>Раньше, чем:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="364"/>
        <source>Later than:</source>
        <translation>Позже, чем:</translation>
    </message>
</context>
</TS>
